Index: printing/backend/print_backend_dummy.cc |
=================================================================== |
--- printing/backend/print_backend_dummy.cc (revision 0) |
+++ printing/backend/print_backend_dummy.cc (working copy) |
@@ -2,27 +2,22 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
// This is dummy implementation for all configurations where print system |
// for cloud print is not available. |
#if !defined(CP_PRINT_SYSTEM_AVAILABLE) |
#include "chrome/service/cloud_print/print_system.h" |
#include "base/logging.h" |
-namespace cloud_print { |
+namespace printing { |
-std::string PrintSystem::GenerateProxyId() { |
+scoped_refptr<PrintBackend> PrintBackend::CreateInstance( |
+ const DictionaryValue* print_backend_settings) { |
NOTREACHED(); |
- return std::string(); |
-} |
- |
-scoped_refptr<PrintSystem> PrintSystem::CreateInstance( |
- const DictionaryValue* print_system_settings) { |
- NOTREACHED(); |
return NULL; |
} |
-} // namespace cloud_print |
-#endif // CP_PRINT_SYSTEM_AVAILABLE |
+} // namespace printing |
+#endif // PRINT_BACKEND_AVAILABLE |
Property changes on: printing/backend/print_backend_dummy.cc |
___________________________________________________________________ |
Added: svn:mergeinfo |
@@ -2,27 +2,22 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-// This is dummy implementation for all configurations where print system |
-// for cloud print is not available. |
-#if !defined(CP_PRINT_SYSTEM_AVAILABLE) |
+// This is dummy implementation for all configurations where there is no |
+// print backend. |
+#if !defined(PRINT_BACKEND_AVAILABLE) |
-#include "chrome/service/cloud_print/print_system.h" |
+#include "printing/backend/print_backend.h" |
#include "base/logging.h" |